@@ -1004,6 +1004,75 @@ value open_etc_file fname =
       try Some (Secure.open_in fname2) with [ Sys_error _ -> None ] ]
 ;
 
+value open_templ conf name =
+  (* On cherche le fichier dans cet ordre :
+     - dans la base (bases/etc/templx/name.txt)
+     - dans le rpertoire des programmes (gw/etc/templx/name.txt)
+     - le template par dfaut (gw/etc/name.txt) *)
+  let file_exist dir = 
+    let base_tpl_dir = 
+      Filename.concat 
+        (base_path ["etc"] (Filename.basename dir)) (name ^ ".txt")
+    in
+    let etc_tpl_dir = 
+      Filename.concat 
+        (search_in_lang_path "etc") (Filename.concat dir ((name ^ ".txt")))
+    in
+    if Sys.file_exists base_tpl_dir then base_tpl_dir
+    else
+      if Sys.file_exists etc_tpl_dir then etc_tpl_dir
+      else ""
+  in
+  (* Recherche le template par dfaut en fonction de la variable gwf *)
+  (* template = templ1,templ2,*                                      *)
+  let rec default_templ config_templ std_fname =
+    match config_templ with
+    [ [] | ["*"] -> std_fname
+    | [x :: l] -> 
+        match file_exist x with
+        [ "" -> default_templ l std_fname 
+        | s -> s ] ]
+  in
+  let config_templ =
+    try
+      let s = List.assoc "template" conf.base_env in
+      let rec loop list i len =
+        if i = String.length s then List.rev [Buff.get len :: list]
+        else if s.[i] = ',' then loop [Buff.get len :: list] (i + 1) 0
+        else loop list (i + 1) (Buff.store len s.[i])
+      in
+      loop [] 0 0
+    with
+    [ Not_found -> [conf.bname; "*"] ]
+  in
+  let dir =
+    match p_getenv conf.env "templ" with
+    [ Some x when List.mem "*" config_templ -> x
+    | Some x when List.mem x config_templ -> x
+    | Some _ | None ->
+        match config_templ with
+        [ [] | ["*"] -> ""
+        | [x :: _] -> x ] ]
+  in
+  (* template par dfaut *)
+  let std_fname =
+    search_in_lang_path (Filename.concat "etc" (name ^ ".txt"))
+  in
+  (* On cherche le template dans l'ordre de file_exist.         *)
+  (* Si on ne trouve rien, alors on cherche le premier template *)
+  (* par dfaut tel que dfini par la variable template du gwf  *)
+  let fname =
+    match file_exist dir with
+    [ "" -> default_templ config_templ std_fname 
+    | s -> s ]
+  in
+  try Some (Secure.open_in fname) with
+  [ Sys_error _ ->
+      if (*dir = conf.bname*)True(**) then
+        try Some (Secure.open_in std_fname) with [ Sys_error _ -> None ]
+      else None ]
+;
+
 value macro_etc env imcom c =
   try List.assoc c env () with
   [ Not_found ->
@@ -1334,7 +1403,7 @@ value default_good_tag_list =
   ["a"; "b"; "blockquote"; "br"; "center"; "cite"; "dd"; "dir"; "div"; "dl";
    "dt"; "em"; "font"; "hr"; "h1"; "h2"; "h3"; "h4"; "h5"; "h6"; "i"; "img";
    "li"; "ol"; "p"; "pre"; "span"; "strong"; "sub"; "sup"; "table"; "tbody";
-   "td"; "th"; "tr"; "tt"; "u"; "ul"; "!--"]
+   "td"; "th"; "tr"; "tt"; "u"; "ul"; "!--"; "area"; "map"]
 ;
 
 value allowed_tags_file = ref "";
@@ -2077,7 +2146,8 @@ value create_topological_sort conf base =
       lock (Mutil.lock_file bfile) with
       [ Accept ->
           let tstab_file =
-            if conf.use_restrict then Filename.concat bfile "tstab_visitor"
+            if conf.use_restrict && not conf.wizard && not conf.friend then 
+              Filename.concat bfile "tstab_visitor"
             else Filename.concat bfile "tstab"
           in
           let r =
@@ -2101,7 +2171,8 @@ value create_topological_sort conf base =
               let () = load_couples_array base in
               let tstab = Consang.topological_sort base (pget conf) in
               do {
-                if conf.use_restrict then base_visible_write base else ();
+                if conf.use_restrict && not conf.wizard && not conf.friend then 
+                  base_visible_write base else ();
                 match
                   try Some (Secure.open_out_bin tstab_file) with
                   [ Sys_error _ -> None ]
